@@ -1,21 +1,13 @@
-from typing import Dict
-from deepfos_ipc_protocol.const import (
-    HEADER_REVERSE_FIELD_MAP,
-    SUBTASKUPDATE_META,
-    SUBTASKUPDATE_FIELD_MAP,
-    SUBTASKUPDATE_REVERSE_FIELD_MAP,
-    SUBTASKINIT_META,
-    SUBTASKINIT_FIELD_MAP,
-    SUBTASKINIT_REVERSE_FIELD_MAP,
-    HEADER_META,
-    HEADER_FIELD_MAP,
-    MESSAGE_PROTOCOL,
-    HEADER_PROTOCOL,
-    DETAILLIST_PROTOCOL
-)
-
 import sys
 import logging
+from typing import Dict
+from configs import const
+
+
+HEADER_PROTOCOL = const.HEADER_PROTOCOL
+MESSAGE_PROTOCOL = const.MESSAGE_PROTOCOL
+DETAILLIST_PROTOCOL = const.DETAILLIST_PROTOCOL
+PROTOCOL_MAP = const.PROTOCOL_MAP
 
 
 logging.basicConfig(
@@ -61,21 +53,13 @@ def judge_data_format(mtype, data):
 
 def get_filed_map(mtype, reverse: bool) -> Dict[str, str]:
     '''获取字段映射表'''
-    if mtype in HEADER_META:
-        if reverse:
-            return HEADER_REVERSE_FIELD_MAP
-        return HEADER_FIELD_MAP
-    elif mtype in SUBTASKUPDATE_META:
-        if reverse:
-            return SUBTASKUPDATE_REVERSE_FIELD_MAP
-        return SUBTASKUPDATE_FIELD_MAP
-    elif mtype in SUBTASKINIT_META:
-        if reverse:
-            return SUBTASKINIT_REVERSE_FIELD_MAP
-        return SUBTASKINIT_FIELD_MAP
-    else:
-        logger.error(f"Unknown meta type: {mtype}")
-        raise ValueError("Unknown meta type: {}".format(mtype))
+    for t, v in PROTOCOL_MAP.items():
+        if mtype in t:
+            if reverse:
+                return v["reverse"]
+            return v["fields"]
+    logger.error(f"Unknown meta type: {mtype}")
+    raise ValueError("Unknown meta type: {}".format(mtype))
 
 
 def _to_filed_protocol(mtype: str, d: Dict[str, str]) -> bytes:
@@ -86,7 +70,7 @@ def _to_filed_protocol(mtype: str, d: Dict[str, str]) -> bytes:
     for index, key in field_map.items():
         if key not in reversed_field_map:
             continue
-        vlen = int_to_int32(len(d[key]))
+        vlen = int_to_int32(len(d[key].encode("utf8")))
         buf += index + vlen + d[key].encode("utf8")
     return buf
 
@@ -111,7 +95,6 @@ def resolve_field_protocol(mtype, num_fields, buf: bytes) -> Dict[str, str]:
     if ptr != buf_len or num_fields != 0:
         logger.error("Bad message")
         raise ValueError("Bad message")
-
     return result
 
 # ------------------message protocol------------------
@@ -120,7 +103,7 @@ def resolve_field_protocol(mtype, num_fields, buf: bytes) -> Dict[str, str]:
 def to_msg_protocol(mtype: str, body: str) -> bytes:
     '''message protocol'''
     mtype = mtype.encode("utf8")
-    mlen = int_to_int32(len(body))
+    mlen = int_to_int32(len(body.encode("utf8")))
     body = body.encode("utf8")
     return mtype + mlen + body
 
@@ -128,7 +111,7 @@ def to_msg_protocol(mtype: str, body: str) -> bytes:
 def resolve_msg_protocol(buf: bytes) -> str:
     '''解析message protocol'''
     str_len = read_int32(buf[1:5])
-    return buf[5: 5+str_len].decode("utf8")
+    return buf[5: 5+str_len].decode("utf-8")
 
 
 # ------------------header protocol------------------
